@@ -28,6 +28,16 @@ class SmartoolsRow(Row):
             self._cells._store.load(value)
         else:
             self._cells.load(value)
+
+    def __getattr__(self, key):
+        if key == 'children':
+            return self._get_children()
+        return super().__getattr__(key)
+
+    def _get_children(self):
+        if hasattr(self, '_list') is not None:
+            return self._list.__get_children__(self.id)
+        return None
         
     # def __getattr__(self, key):
     #     if key == 'format':
